install.packages("tm")
install.packages("readxl")
install.packages("openxlsx")

library(tm)
library(readxl)
library(openxlsx)

ia_researchers_df <- read_excel("IAM researchers with unique surnames.xlsx")
ia_researchers <- as.character(ia_researchers_df$`IA.researchers`)
inputs <- read_excel("inputs.xlsx")
results_table <- read_excel("Results table template.xlsx")
outputs <- read_excel("outputs.xlsx")

preprocess_text <- function(text) {
  text <- tolower(text)  # Convert to lowercase
  text <- removePunctuation(text)  # Remove punctuation
  text <- removeNumbers(text)  # Remove numbers
  text <- stripWhitespace(text)  # Remove extra white spaces
  text <- removeWords(text, stopwords("en"))  # Remove common English stopwords
  return(text)
}

for (i in 1:nrow(inputs)) {
    input_excel_filename <- as.character(inputs[i, 1])
    sheet <- read_excel(input_excel_filename)
    instances_df <- data.frame()
    
    for (j in 1:nrow(sheet)) {
      text <- preprocess_text(sheet[[1]][j])  # Preprocess the text in the current row
      words <- unlist(strsplit(text, " "))  # Split the text into words
      # Check if the specific word appears in this row
      if (any(words %in% ia_researchers)) {
        # If yes, add this row to instances_df
        instances_df <- rbind(instances_df, sheet[j, ])
      }
    }
    output_instances_file <- as.character(outputs[i, 1])
    results_table$`Number of references`[i] <- nrow(instances_df)
    write.xlsx(instances_df, output_instances_file, rowNames = FALSE)
}

write.xlsx(results_table, "Chapter-level results.xlsx", rowNames = FALSE)
