install.packages("tm")
install.packages("readxl")
install.packages("openxlsx")

# Load required libraries
library(tm)
library(readxl)
library(openxlsx)

# Specify IAM researchers
ia_researchers <- read_excel("IA-researchers.xlsx")

# Read inputs
inputs <- read_excel("inputs.xlsx")

# Read outputs
outputs <- read_excel("outputs.xlsx")

# Read results table
results_table <- read_excel("results_table_template.xlsx")

# Create a function to preprocess text data
preprocess_text <- function(text) {
  text <- tolower(text)  # Convert to lowercase
  text <- removePunctuation(text)  # Remove punctuation
  text <- removeNumbers(text)  # Remove numbers
  text <- stripWhitespace(text)  # Remove extra white spaces
  text <- removeWords(text, stopwords("en"))  # Remove common English stopwords
  return(text)
}

for (i in 1:nrow(ia_researchers)) {
  
  specific_word <- as.character(ia_researchers[i, 1])  # Extract the specific word from the data frame
  
  # Print a message indicating the specific word
  cat("The specific word is", specific_word, "\n")
  
    # Extract the Excel file name from the 'inputs' dataframe at row 'i'
    input_excel_filename <- as.character(inputs[i, 1])
    
    # Print a message indicating the specific word
    cat("The input is", input_excel_filename, "\n")
    
    # Read the AR file
    sheet <- read_excel(input_excel_filename)
    
    # Create an empty data frame to store instances
    instances_df <- data.frame()
    
    for (j in 1:nrow(sheet)) {
      text <- preprocess_text(sheet[[1]][j])  # Preprocess the text in the current row
      words <- unlist(strsplit(text, " "))  # Split the text into words
      
      # Check if the specific word appears in this row
      if (specific_word %in% words) {
        # If yes, add this row to instances_df
        instances_df <- rbind(instances_df, sheet[j, ])
        print("Specific word found")
      }
    }
    
    # Extract the Excel file name from the 'outputs' dataframe at row 'i'
    output_instances_file <- as.character(outputs[i, 1])
    
    # Save number of instances to results table dataframe
    results_table$`Number of references`[i] <- nrow(instances_df)
    
    # Save instances_df as a new Excel file
    write.xlsx(instances_df, output_instances_file, rowNames = FALSE)
    
    # Print a message indicating successful save
    cat("Instances with the specific word saved to", output_instances_file, "\n")
}

write.xlsx(results_table, "Results.xlsx", rowNames = FALSE)

