install.packages("tm")
install.packages("readxl")
install.packages("openxlsx")

# Load required libraries
library(tm)
library(readxl)
library(openxlsx)

sequence <- seq(5, 185, by = 10)

for (x in sequence) {
  
# Manually create a character vector
ia_researchers_df <- read_excel(paste0("Data/", x, ".xlsx"))

# Assuming "df" is your dataframe
ia_researchers <- as.character(ia_researchers_df$`IA.researchers`)

# Read inputs
inputs <- read_excel("Inputs.xlsx")

# Read results table
results_table <- read_excel("Results table template.xlsx")

# Read outputs
outputs <- read_excel(paste0("Outputs/", x,".xlsx"))

# Create a function to preprocess text data
preprocess_text <- function(text) {
  text <- tolower(text)  # Convert to lowercase
  text <- removePunctuation(text)  # Remove punctuation
  text <- removeNumbers(text)  # Remove numbers
  text <- stripWhitespace(text)  # Remove extra white spaces
  text <- removeWords(text, stopwords("en"))  # Remove common English stopwords
  return(text)
}

for (i in 1:nrow(inputs)) {
  
    # Extract the Excel file name from the 'inputs' dataframe at row 'i'
    input_excel_filename <- as.character(inputs[i, 1])
    
    # Print a message indicating the specific word
    cat("The input is", input_excel_filename, "\n")
    
    # Read the AR file
    sheet <- read_excel(input_excel_filename)
    
    # Create an empty data frame to store instances
    instances_df <- data.frame()
    
    for (j in 1:nrow(sheet)) {
      text <- preprocess_text(sheet[[1]][j])  # Preprocess the text in the current row
      words <- unlist(strsplit(text, " "))  # Split the text into words
      
      # Check if any of the specific words appear in this row
      if (any(words %in% ia_researchers)) {
        # If yes, add this row to instances_df
        instances_df <- rbind(instances_df, sheet[j, ])
        print("Specific word found")
      }
    }
    
    # Extract the Excel file name from the 'outputs' dataframe at row 'i'
    output_instances_file <- as.character(outputs[i, 1])
    
    # Save the number of instances to results table dataframe
    results_table$`Number of references`[i] <- nrow(instances_df)
    
    # Save instances_df as a new Excel file
    write.xlsx(instances_df, paste0(output_instances_file,".xlsx"), rowNames = FALSE)
    
    # Print a message indicating successful save
    cat("Instances with any of the specific words saved to", output_instances_file, "\n")
}

# Save the updated results table as a new Excel file for the current x
write.xlsx(results_table, paste0("Result tables/", x, ".xlsx"), rowNames = FALSE)
}