install.packages("tm")
install.packages("readxl")
install.packages("openxlsx")
install.packages("dplyr")

library(tm)
library(readxl)
library(openxlsx)
library(dplyr)

researchers_df <- read_excel("Sorted_SAR_results.xlsx")
non_unique_researchers <- read_excel("Cumulative non-unique.xlsx")
sheet <- read_excel("AR2/AR2.xlsx")
corrections <- read_excel("Corrections.xlsx")

filtered_corrections <- corrections %>%
  filter(AR == "SAR")

filtered_researchers_df <- researchers_df %>% 
  filter(`Contribution share` != 0)  %>% 
  select (Researcher)

matched_rows <- c()
references <- c()

# Apply the function with row number tracking and update 'corrections'
filtered_researchers_df$Researcher <- sapply(seq_along(filtered_researchers_df$Researcher), function(i) {
  researcher <- filtered_researchers_df$Researcher[i]
  
  # Check if the researcher is in 'non_unique_researchers'
  if (researcher %in% non_unique_researchers$researchers) {
    # Save the row number if condition is true
    matched_rows <<- c(matched_rows, i)
    
    # Find the corresponding row in 'corrections' dataframe
    correction_index <- which(filtered_corrections$researchers == researcher)
    
    # Update the 'Additional number of references' column in 'corrections' dataframe
    if (length(correction_index) > 0) {
      references <<- c(references, filtered_corrections$`Additional number of references`[correction_index])
    }
    
    return(paste0(researcher, "123"))
  } else {
    return(researcher)
  }
})

corrections_df <- data.frame(
  `Matched rows` = matched_rows,
  References = references
)

num_rows <- nrow(filtered_researchers_df)

output_file_paths <- paste0("AR2/results/", num_rows:1, ".xlsx")
outputs <- data.frame(output_file_path = output_file_paths)

num_researchers <- paste0(num_rows:1)
results_table <- data.frame("Number of researchers" = num_researchers)
results_table$`Number of references` <- NA

preprocess_text <- function(text) {
  text <- tolower(text)  # Convert to lowercase
  text <- removePunctuation(text)  # Remove punctuation
  text <- removeNumbers(text)  # Remove numbers
  text <- stripWhitespace(text)  # Remove extra white spaces
  text <- removeWords(text, stopwords("en"))  # Remove common English stopwords
  return(text)
}

for (i in 1:nrow(filtered_researchers_df)) {
  
  ia_researchers <- as.character(filtered_researchers_df$`Researcher`)
  cat("Number of rows in filtered_researchers_df:", nrow(filtered_researchers_df))
  instances_df <- data.frame()
  
  for (j in 1:nrow(sheet)) {
    text <- preprocess_text(sheet[[1]][j])  # Preprocess the text in the current row
    words <- unlist(strsplit(text, " "))  # Split the text into words
    # Check if the specific word appears in this row
    if (any(words %in% ia_researchers)) {
      # If yes, add this row to instances_df
      instances_df <- rbind(instances_df, sheet[j, ])
      print("Specific word found")
    }
  }
  
  output_instances_file <- as.character(outputs[i, 1])
  results_table$`Number of references`[i] <- nrow(instances_df)
  write.xlsx(instances_df, output_instances_file, rowNames = FALSE)
  cat("Instances with any of the specific word saved to", output_instances_file, "\n")
  
  filtered_researchers_df <- filtered_researchers_df[-nrow(filtered_researchers_df), ]
}

update_references <- function(corrections_df, results_table) {
  for (k in 1:nrow(corrections_df)) {
    target_row <- num_rows + 1 - corrections_df$`Matched.rows`[k]
    for (h in target_row:1) {
      results_table[h, "Number of references"] <- results_table[h, "Number of references"] + corrections_df$References[k]
    }
  }
  return(results_table)
}

updated_results_table <- update_references(corrections_df, results_table)

clean_results_table <- function(results_table) {
  rows_to_delete <- integer()
  
  for (j in 2:nrow(results_table)) {
    if (results_table[j, "Number of references"] == results_table[j - 1, "Number of references"]) {
      rows_to_delete <- c(rows_to_delete, j - 1)
    }
  }
  rows_to_delete <- unique(rows_to_delete)
  results_table <- results_table[-sort(rows_to_delete), ]
  
  return(results_table)
}

cleaned_results_table <- clean_results_table(updated_results_table)
cleaned_results_table$Number.of.researchers <- seq(from = nrow(cleaned_results_table), to = 1)

filtered_researchers_df <- researchers_df %>% 
  filter(`Contribution share` != 0)  %>% 
  select (Researcher)

clean_researchers_list <- function(results_table, researchers_list) {
  rows_to_delete <- integer()
  
  for (j in 2:nrow(results_table)) {
    if (results_table[j, "Number of references"] == results_table[j - 1, "Number of references"]) {
      rows_to_delete <- c(rows_to_delete, (num_rows-j+2))
    }
  }
  
  rows_to_delete <- unique(rows_to_delete)
  print(rows_to_delete)
  rows_to_delete <- sort(rows_to_delete, decreasing = TRUE)
  researchers_list <- researchers_list[-rows_to_delete, ]
  
  return(researchers_list)
}

cleaned_researchers_list <- clean_researchers_list(updated_results_table, filtered_researchers_df)

write.xlsx(cleaned_results_table,"AR2/AR2-results-corrected.xlsx")
write.xlsx(cleaned_researchers_list,"AR2/AR2-results-researchers.xlsx")