install.packages("tm")
install.packages("readxl")
install.packages("openxlsx")

library(tm)
library(readxl)
library(openxlsx)

# Specify the Excel file you want to process
excel_file <- "TAR.xlsx"

# Create a function to preprocess text data
preprocess_text <- function(text) {
  text <- tolower(text)  # Convert to lowercase
  text <- removePunctuation(text)  # Remove punctuation
  text <- removeNumbers(text)  # Remove numbers
  text <- stripWhitespace(text)  # Remove extra white spaces
  text <- removeWords(text, stopwords("en"))  # Remove common English stopwords
  return(text)
}

sheet <- read_excel(excel_file)  # Read the Excel sheet
text <- paste(sheet[[1]], collapse = " ")  # Use the first column for text data
text <- preprocess_text(text)  # Preprocess the text

# Create a corpus from the processed text
corpus <- Corpus(VectorSource(text))

# Create a Document-Term Matrix (DTM)
dtm <- DocumentTermMatrix(corpus)

# Convert DTM to a matrix
dtm_matrix <- as.matrix(dtm)

# Get the most common words
most_common_words <- names(sort(colSums(dtm_matrix), decreasing = TRUE))[1:75]

# Create a data frame for the most common words and their frequencies
common_words_df <- data.frame(Word = most_common_words)
common_words_df$Frequency <- sapply(most_common_words, function(word) sum(dtm_matrix[, word]))

output_file <- "TAR-results.xlsx"
write.xlsx(common_words_df, output_file, rowNames = FALSE)
